CCL: /home/chisarie/Documents/lsst_ccl/CCL/include/ccl_error.h Source File

CCL

ccl_error.h
Go to the documentation of this file.
1
3 #pragma once
4 #include "ccl_core.h"
5
6 #define CCL_ERROR_MEMORY 1
7 #define CCL_ERROR_LINSPACE 2
8 #define CCL_ERROR_INCONSISTENT 3
9 #define CCL_ERROR_SPLINE 4
10 #define CCL_ERROR_SPLINE_EV 5
11 #define CCL_ERROR_INTEG 6
12 #define CCL_ERROR_ROOT 7
13 #define CCL_ERROR_CLASS 8
14 #define CCL_ERROR_COMPUTECHI 9
15 #define CCL_ERROR_MF 10
16 #define CCL_ERROR_HMF_INTERP 11
17 #define CCL_ERROR_PARAMETERS 12
18 #define CCL_ERROR_NU_INT 13
19
20 typedef enum {
21 CCL_ERROR_POLICY_EXIT = 0,
22 CCL_ERROR_POLICY_CONTINUE = 1,
23 } CCLErrorPolicy;
24
29 void ccl_raise_exception(int err, char* msg);
30
35 void ccl_set_error_policy(CCLErrorPolicy error_policy);
36
42 void ccl_check_status(ccl_cosmology *cosmo, int* status);
43
49 void ccl_check_status_nocosmo(int* status);
ccl_check_status
void ccl_check_status(ccl_cosmology *cosmo, int *status)
Definition: ccl_error.c:25
CCLErrorPolicy
CCLErrorPolicy
Definition: ccl_error.h:20
ccl_core.h
CCL_ERROR_POLICY_CONTINUE
Definition: ccl_error.h:22
ccl_raise_exception
void ccl_raise_exception(int err, char *msg)
Definition: ccl_error.c:17
ccl_check_status_nocosmo
void ccl_check_status_nocosmo(int *status)
Definition: ccl_error.c:50
ccl_set_error_policy
void ccl_set_error_policy(CCLErrorPolicy error_policy)
Definition: ccl_error.c:12
ccl_cosmology
Definition: ccl_core.h:115
CCL_ERROR_POLICY_EXIT
Definition: ccl_error.h:21